@@ -7,5 +7,8 @@ TRANSACTION_INVESTOR_ACTIONS = {'Subscription', 'Redemption'}
 TRANSACTION_LIFECYCLE_ACTIONS = {'Acquire', 'Remove'}
 TRANSACTION_ACTIONS = {'Buy', 'Sell', 'Short Sell', 'Short Cover', 'Deliver', 'Receive'} | \
                       TRANSACTION_LIFECYCLE_ACTIONS | TRANSACTION_INVESTOR_ACTIONS
+TRANSACTION_ACQUIRE_ACTIONS = {'Buy', 'Short Cover', 'Receive', 'Acquire', 'Redemption'}
+TRANSACTION_REMOVE_ACTIONS = {'Sell', 'Short Sell', 'Deliver', 'Remove', 'Subscription'}
 TRANSACTION_CANCEL_STATUSES = {'Cancelled', 'Netted', 'Novated'}
 TRANSACTION_STATUSES = {'New', 'Amended', 'Superseded'} | TRANSACTION_CANCEL_STATUSES
+ACCOUNTING_TYPES = {'Transaction Date', 'Settlement Date'}
